==> nextcloud-12.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/sk.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Aktivity",
    "No activity yet" : "Zatiaľ žiadne aktivity.",
    "Load more activities" : "Načítať viac aktivít",
    "Copied!" : "Skopírované!",
    "Not supported!" : "Nie je podporované!",
    "Press ⌘-C to copy." : "Stlač ⌘-C pre skopírovanie.",
    "Press Ctrl-C to copy." : "Stlač Ctrl-C pre skopírovanie.",
    "{name} (invisible)" : "{name} (neviditeľné)",
    "{name} (restricted)" : "{name} (obmedzené)",
    "in {path}" : "v {path}",
    "This stream will show events like additions, changes & shares" : "Tento dátový prúd zobrazuje udalosti ako pridanie, zmeny a sprístupnenie",
    "There are no events for this filter" : "Pre tieto kritériá nie sú žiadne udalosti",
    "Today" : "Dnes",
    "Yesterday" : "Včera",
    "Personal activity feed for %s" : "Prehľad aktivít pre používateľa %s",
    "Your feed URL is invalid" : "Váš kanál URL je neplatný",
    "Your settings have been updated." : "Vaše nastavenia boli aktualizované.",
    "Mail" : "Pošta",
    "Stream" : "Stream",
    "All activities" : "Všetky aktivity",
    "By others" : "Aktivity ostatných",
    "By you" : "Vlastné aktivity",
    "\"remote user\"" : "\"vzdialený používateľ\"",
    "Hello %s," : "Ahoj %s,",
    "There was some activity at %s" : "Bola zaznamenaná aktivita u používateľa %s",
    "Activity notification" : "Upozornenia na aktivity",
    ", " : ", ",
    "%s and %s" : "%s a %s",
    "Activity" : "Aktivita",
    "Activity feed" : "Prehľad aktivít",
    "List your own actions in the stream" : "Zoznam vlastných činností v dátovom prúde",
    "Notify about your own actions via email" : "Poslať oznámenie o vlastnej činnosti emailom",
    "You need to set up your email address before you can receive notification emails." : "Ak chcete dostávať oznámenia emailom, musíte najskôr vyplniť vašu emailovú adresu.",
    "Send emails:" : "Odoslať emaily:",
    "Hourly" : "Každú hodinu",
    "Daily" : "Denne",
    "Weekly" : "Týždenne",
    "Enable RSS feed" : "Povoliť RSS kanál",
    "No more events to load" : "Žiadne ďalšie udalosti na načítanie",
    "Files" : "Súbory"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");

==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/sk.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Aktivity",
    "An error occurred while loading activities" : "Pri pokuse o načítanie aktivity nastala chyba",
    "No activity yet" : "Zatiaľ žiadne aktivity.",
    "Load more activities" : "Načítať viac aktivít",
    "Copied!" : "Skopírované!",
    "Not supported!" : "Nie je podporované!",
    "Press ⌘-C to copy." : "Stlač ⌘-C pre skopírovanie.",
    "Press Ctrl-C to copy." : "Stlač Ctrl-C pre skopírovanie.",
    "{name} (invisible)" : "{name} (neviditeľné)",
    "{name} (restricted)" : "{name} (obmedzené)",
    "in {path}" : "v {path}",
    "This stream will show events like additions, changes & shares" : "Tento dátový prúd zobrazuje udalosti ako pridanie, zmeny a sprístupnenie",
    "There are no events for this filter" : "Pre tieto kritériá nie sú žiadne udalosti",
    "Today" : "Dnes",
    "Yesterday" : "Včera",
    "Personal activity feed for %s" : "Prehľad aktivít pre používateľa %s",
    "Your feed URL is invalid" : "Váš kanál URL je neplatný",
    "Your settings have been updated." : "Vaše nastavenia boli aktualizované.",
    "Settings have been updated." : "Nastavenia boli aktualizované.",
    "Mail" : "Pošta",
    "Stream" : "Stream",
    "All activities" : "Všetky aktivity",
    "By others" : "Aktivity ostatných",
    "By you" : "Vlastné aktivity",
    "\"remote user\"" : "\"vzdialený používateľ\"",
    "Hello %s" : "Ahoj %s",
    "Hello %s," : "Ahoj %s,",
    "There was some activity at %s" : "Bola zaznamenaná aktivita u používateľa %s",
    "_and %n more _::_and %n more _" : ["a %n ďalší","a %n ďalšie","a %n ďalších"],
    "Activity notification" : "Upozornenia na aktivity",
    ", " : ", ",
    "%s and %s" : "%s a %s",
    "Activity" : "Aktivita",
    "Activity feed" : "Prehľad aktivít",
    "Configure the default activity settings for new users." : "Upravte predvolené nastavenia aktivít pre nových používateľov.",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "Vyberte na ktoré aktivity chcete byť upozornení emailovou notifikáciou a ktore sa majú zobraziť v dátovom prúde.",
    "List your own actions in the stream" : "Zoznam vlastných činností v dátovom prúde",
    "Notify about your own actions via email" : "Poslať oznámenie o vlastnej činnosti emailom",
    "You need to set up your email address before you can receive notification emails." : "Ak chcete dostávať oznámenia emailom, musíte najskôr vyplniť vašu emailovú adresu.",
    "Send emails:" : "Odoslať emaily:",
    "Hourly" : "Každú hodinu",
    "Daily" : "Denne",
    "Weekly" : "Týždenne",
    "Settings" : "Nastavenia",
    "Enable RSS feed" : "Povoliť RSS kanál",
    "No more events to load" : "Žiadne ďalšie udalosti na načítanie",
    "Files" : "Súbory",
    "Error loading activities" : "Chyba pri načítaní aktivít",
    "No activities" : "Žiadne aktivity",
    "You are receiving this email because the following things happened at %s" : "Tento mail dostávate ako upozorenie na nasledujúce odalosti na %s",
    "* %1$s - %2$s" : "%1$s - %2$s ",
    "_* and %n more _::_* and %n more _" : ["* a %n ďalšia","* a %n ďalšie","* a %n ďalších"]
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
